powered by
Downloads zipped ppmf files from GitHub.
download_ppmf(dsn, dir = "", version = "19", overwrite = FALSE)
(data save name) string to unzip the data to
the folder or directory to save the file in
string in '19', '12' or '4' signifying the 19.61, 12.2 or 4.5 versions respectively
If a file is found at path/dsn, should it be overwritten? Defaults to FALSE.
a string path to where the file was downloaded to
# NOT RUN { # Takes a few minutes and requires read access to files temp <- tempdir() path <- download_ppmf(dsn = 'ppmf_12', dir = temp) # }
Run the code above in your browser using DataLab